@@ -1,5 +1,5 @@
 # Curses-based interfaces
-# Copyright (C) 2003-2015 John Goerzen & contributors
+# Copyright (C) 2003-2018 John Goerzen & contributors.
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -149,6 +149,7 @@ class CursesAccountFrame:
         self.window = curses_win
         self.acc_num = acc_num
         self.drawleadstr()
+        self.ui.exec_locked(self.window.noutrefresh)
         # Update the child ThreadFrames
         for child in self.children:
             child.update(curses_win, self.location, 0)
@@ -314,11 +315,11 @@ class CursesLogHandler(logging.StreamHandler):
             y,x = self.ui.logwin.getyx()
             if y or x: self.ui.logwin.addch(10) # no \n before 1st item
             self.ui.logwin.addstr(log_str, color)
+            self.ui.logwin.noutrefresh()
+            self.ui.stdscr.refresh()
         finally:
             self.ui.unlock()
             self.ui.tframe_lock.release()
-        self.ui.logwin.noutrefresh()
-        self.ui.stdscr.refresh()
 
 class Blinkenlights(UIBase, CursesUtil):
     """Curses-cased fancy UI.
@@ -442,6 +443,10 @@ class Blinkenlights(UIBase, CursesUtil):
         self.gettf().setcolor('blue')
         super(Blinkenlights, self).syncingmessages(*args)
 
+    def ignorecopyingmessage(self, *args):
+        self.gettf().setcolor('red')
+        super(Blinkenlights, self).ignorecopyingmessage(*args)
+
     def copyingmessage(self, *args):
         self.gettf().setcolor('orange')
         super(Blinkenlights, self).copyingmessage(*args)
@@ -506,6 +511,7 @@ class Blinkenlights(UIBase, CursesUtil):
         # received special KEY_RESIZE, resize terminal
         if key == curses.KEY_RESIZE:
             self.resizeterm()
+            return
 
         if key < 1 or key > 255:
             return
@@ -543,7 +549,7 @@ class Blinkenlights(UIBase, CursesUtil):
     def mainException(self):
         UIBase.mainException(self)
 
-    def getpass(self, accountname, config, errmsg=None):
+    def getpass(self, username, config, errmsg=None):
         # disable the hotkeys inputhandler
         self.inputhandler.input_acquire()
 
@@ -552,8 +558,8 @@ class Blinkenlights(UIBase, CursesUtil):
         try:
             #s.gettf().setcolor('white')
             self.warn(" *** Input Required")
-            self.warn(" *** Please enter password for account %s: " % \
-                          accountname)
+            self.warn(" *** Please enter password for user '%s': " % \
+                          username)
             self.logwin.refresh()
             password = self.logwin.getstr()
         finally:
@@ -570,9 +576,12 @@ class Blinkenlights(UIBase, CursesUtil):
         self.height, self.width = self.stdscr.getmaxyx()
         self.logheight = self.height - len(self.accframes) - 1
         if resize:
-            curses.resizeterm(self.height, self.width)
+            if curses.is_term_resized(self.height, self.width):
+                curses.resizeterm(self.height, self.width)
             self.bannerwin.resize(1, self.width)
             self.logwin.resize(self.logheight, self.width)
+            self.stdscr.clear()
+            self.stdscr.noutrefresh()
         else:
             self.bannerwin = curses.newwin(1, self.width, 0, 0)
             self.logwin = curses.newwin(self.logheight, self.width, 1, 0)
@@ -602,11 +611,12 @@ class Blinkenlights(UIBase, CursesUtil):
             color = curses.A_REVERSE
         self.bannerwin.clear() # Delete old content (eg before resizes)
         self.bannerwin.bkgd(' ', color) # Fill background with that color
-        string = "%s %s"% (offlineimap.__productname__,
-            offlineimap.__version__)
-        self.bannerwin.addstr(0, 0, string, color)
-        self.bannerwin.addstr(0, self.width -len(offlineimap.__copyright__) -1,
-                              offlineimap.__copyright__, color)
+        string = "%s %s" % (offlineimap.__productname__,
+                            offlineimap.__version__)
+        spaces = " " * max(1, (self.width - len(offlineimap.__copyright__)
+                               - len(string) - 1))
+        string = "%s%s%s" % (string, spaces, offlineimap.__copyright__)
+        self.bannerwin.addnstr(0, 0, string, self.width - 1, color)
         self.bannerwin.noutrefresh()
 
     def draw_logwin(self):
@@ -617,8 +627,9 @@ class Blinkenlights(UIBase, CursesUtil):
         else:
             color = curses.A_NORMAL
         self.logwin.move(0, 0)
-        self.logwin.erase()
+        self.logwin.clear()
         self.logwin.bkgd(' ', color)
+        self.logwin.noutrefresh()
 
     def getaccountframe(self, acc_name):
         """Return an AccountFrame() corresponding to acc_name.
